@@ -72,6 +72,10 @@ private:
 
     void resetDisplays();
 
+    void checkVersion();
+
+    void saveSettings();    // This method is called when the program is closed
+
     QString renameFileNameOnPrefixSuffix(QString oldFileName);
     QString renameFileNameOnProgressiveN(QString oldFileName);
     QString destinationPath();
@@ -102,6 +106,10 @@ private slots:
     void loadFiles(QStringList fileNames);
     void openFiles();
     void addFiles();
+    void importIcoFile();
+    void importPdfFile();
+
+    void openMultipageFile(QString fileName);   // !
     void elabora();
     void setCurrentDirectory();
     void openOutDirectory();
@@ -138,6 +146,7 @@ private slots:
     void choseBackgroundColor();
 
     void openPaypalLink();
+    void openFlattrLink();
 
     void checkForUpdates();
     void bugReport();
